/*
Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'image', 'hr', {
	alt: 'Alternativni tekst',
	border: 'Okvir',
	btnUpload: 'Pošalji na server',
	button2Img: 'Želite li promijeniti odabrani gumb u jednostavnu sliku?',
	hSpace: 'HSpace',
	img2Button: 'Želite li promijeniti odabranu sliku u gumb?',
	infoTab: 'Info slike',
	linkTab: 'Veza',
	lockRatio: 'Zaključaj odnos',
	menu: 'Svojstva slika',
	resetSize: 'Obriši veličinu',
	title: 'Svojstva slika',
	titleButton: 'Image Button svojstva',
	upload: 'Pošalji',
	urlMissing: 'Nedostaje URL slike.',
	vSpace: 'VSpace',
	validateBorder: 'Okvir mora biti cijeli broj.',
	validateHSpace: 'HSpace mora biti cijeli broj',
	validateVSpace: 'VSpace mora biti cijeli broj.'
} );
